@@ -8,6 +8,7 @@ import (
 	"github.com/mattn/go-isatty"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
+	filehelpers "github.com/turbot/go-kit/files"
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/error_helpers"
 	"github.com/turbot/steampipe/pkg/filepaths"
@@ -23,29 +24,26 @@ var rootCmd = &cobra.Command{
 	Use:     "steampipe [--version] [--help] COMMAND [args]",
 	Version: version.SteampipeVersion.String(),
 	Short:   "Query cloud resources using SQL",
-	Long: `Query cloud resources using SQL.
-
-The available commands for execution are listed below.
-The most common, useful commands are shown first, followed by
-less common or more advanced commands. If you're just getting
-started with Steampipe, stick with the common commands. For the
-other commands, please read the help and docs before usage.
-
-Getting started:
+	Long: `Steampipe: select * from cloud;
 
+Dynamically query APIs, code and more with SQL.
+Zero-ETL from 140+ data sources.
+	
+Common commands:
+	
   # Interactive SQL query console
   steampipe query
+	
+  # Install a plugin from the hub - https://hub.steampipe.io
+  steampipe plugin install aws
 
   # Execute a defined SQL query
   steampipe query "select * from aws_s3_bucket"
 
-  # Install a plugin
-  steampipe plugin install azure
-
   # Get help for a command
   steampipe help query
-
-  Documentation available at https://steampipe.io/docs
+	
+Documentation: https://steampipe.io/docs
  `,
 }
 
@@ -53,11 +51,13 @@ func InitCmd() {
 	utils.LogTime("cmd.root.InitCmd start")
 	defer utils.LogTime("cmd.root.InitCmd end")
 
+	defaultInstallDir, err := filehelpers.Tildefy(filepaths.DefaultInstallDir)
+	error_helpers.FailOnError(err)
 	rootCmd.SetVersionTemplate(fmt.Sprintf("Steampipe v%s\n", version.SteampipeVersion.String()))
 
 	// global flags
 	rootCmd.PersistentFlags().String(constants.ArgWorkspaceProfile, "default", "The workspace profile to use") // workspace profile profile is a global flag since install-dir(global) can be set through the workspace profile
-	rootCmd.PersistentFlags().String(constants.ArgInstallDir, filepaths.DefaultInstallDir, "Path to the Config Directory")
+	rootCmd.PersistentFlags().String(constants.ArgInstallDir, defaultInstallDir, "Path to the Config Directory")
 	rootCmd.PersistentFlags().Bool(constants.ArgSchemaComments, true, "Include schema comments when importing connection schemas")
 
 	error_helpers.FailOnError(viper.BindPFlag(constants.ArgInstallDir, rootCmd.PersistentFlags().Lookup(constants.ArgInstallDir)))
