@@ -1,6 +1,9 @@
 package dashboardevents
 
-import "github.com/turbot/steampipe/pkg/control/controlstatus"
+import (
+	"github.com/turbot/steampipe/pkg/control/controlstatus"
+	"time"
+)
 
 type ControlError struct {
 	Control     controlstatus.ControlRunStatusProvider
@@ -8,6 +11,7 @@ type ControlError struct {
 	Name        string
 	Session     string
 	ExecutionId string
+	Timestamp   time.Time
 }
 
 // IsDashboardEvent implements DashboardEvent interface
