@@ -15,11 +15,11 @@ import (
 // PluginManagerClient is the client used by steampipe to access the plugin manager
 type PluginManagerClient struct {
 	manager            pluginshared.PluginManager
-	pluginManagerState *PluginManagerState
+	pluginManagerState *State
 	rawClient          *plugin.Client
 }
 
-func NewPluginManagerClient(pluginManagerState *PluginManagerState) (*PluginManagerClient, error) {
+func NewPluginManagerClient(pluginManagerState *State) (*PluginManagerClient, error) {
 	res := &PluginManagerClient{
 		pluginManagerState: pluginManagerState,
 	}
@@ -84,7 +84,9 @@ func (c *PluginManagerClient) RefreshConnections(req *pb.RefreshConnectionsReque
 }
 
 func (c *PluginManagerClient) Shutdown(req *pb.ShutdownRequest) (*pb.ShutdownResponse, error) {
-	log.Printf("[TRACE] PluginManagerClient Shutdown")
+	log.Printf("[DEBUG] PluginManagerClient.Shutdown start")
+	defer log.Printf("[DEBUG] PluginManagerClient.Shutdown done")
+
 	res, err := c.manager.Shutdown(req)
 	if err != nil {
 		return nil, grpc.HandleGrpcError(err, "PluginManager", "Get")
