@@ -2,11 +2,11 @@ package steampipeconfig
 
 import (
 	"fmt"
+	"log"
 	"strings"
 
 	sdkversion "github.com/turbot/steampipe-plugin-sdk/v5/version"
 	"github.com/turbot/steampipe/pkg/constants"
-	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 	"github.com/turbot/steampipe/pkg/utils"
 )
 
@@ -17,6 +17,7 @@ func (u *ConnectionUpdates) validate() {
 }
 
 func (u *ConnectionUpdates) validatePluginsAndConnections() {
+	// TODO should plugin manager do this when starting the plugin???
 	var validatedPlugins = make(map[string]*ConnectionPlugin)
 
 	for connectionName, connectionPlugin := range u.ConnectionPlugins {
@@ -40,15 +41,22 @@ func (u *ConnectionUpdates) validateUpdates() {
 	// ConnectionPlugins has now been validated and only contains valid connection plugins
 	// for every update and comment update, confirm the connection plugin is valid
 	for connectionName, connectionState := range u.Update {
-		if connectionState.GetType() == modconfig.ConnectionTypeAggregator {
-			if u.validateAggregator(connectionState) {
-				validatedUpdates[connectionName] = connectionState
-			}
-		} else if _, ok := u.ConnectionPlugins[connectionName]; ok {
+		if _, ok := u.ConnectionPlugins[connectionName]; ok {
 			// if this connection has a validated connection plugin, add to valdiated updates
 			validatedUpdates[connectionName] = connectionState
+		} else {
+			// try to get the validation failure - should be in InvalidConnections
+			validationFailure, ok := u.InvalidConnections[connectionName]
+			if ok {
+				log.Printf("[WARN] validateUpdates - connection update '%s' failed validation: %s", connectionName, validationFailure.Message)
+			} else {
+				// not expected
+				// for some reason there was no validation failure in the map
+				log.Printf("[WARN] validateUpdates - connection update '%s' failed validation (connection not found in validated ConnectionPlugins but InvalidConnections does not contain the connection - this is unexpected)", connectionName)
+			}
 		}
 	}
+
 	for connectionName, connectionState := range u.MissingComments {
 		// if this connection has a validated connection plugin, add to validated comment updates
 		if _, ok := u.ConnectionPlugins[connectionName]; ok {
@@ -61,23 +69,6 @@ func (u *ConnectionUpdates) validateUpdates() {
 	u.MissingComments = validatedCommentUpdates
 }
 
-func (u *ConnectionUpdates) validateAggregator(connectionState *ConnectionState) bool {
-	connectionName := connectionState.ConnectionName
-	if connectionState.GetType() == modconfig.ConnectionTypeAggregator {
-		// get the connection object
-		connection := GlobalConfig.Connections[connectionName]
-		// get the first child connection
-		for _, childConnection := range connection.Connections {
-			// check whether the plugin for this connection is validated
-			for _, p := range u.ConnectionPlugins {
-				return p.IncludesConnection(childConnection.Name)
-			}
-		}
-	}
-	// treat empty aggregator as validated - we will create a schema for it but not allow querying
-	return true
-}
-
 func validateConnectionName(connectionName string, p *ConnectionPlugin) *ValidationFailure {
 	if err := ValidateConnectionName(connectionName); err != nil {
 		return &ValidationFailure{
