@@ -1,11 +1,12 @@
 package modconfig
 
 import (
+	"strings"
+
 	"github.com/hashicorp/hcl/v2"
-	"github.com/turbot/go-kit/hcl_helpers"
+	"github.com/turbot/pipe-fittings/hclhelpers"
 	"github.com/turbot/steampipe/pkg/ociinstaller"
 	"golang.org/x/exp/maps"
-	"strings"
 )
 
 type Plugin struct {
@@ -18,6 +19,8 @@ type Plugin struct {
 	EndLineNumber   *int           `db:"end_line_number"`
 	// the image ref as a string
 	Plugin string `db:"plugin"`
+	// the actual plugin version, as a string
+	Version string `db:"version"`
 }
 
 // NewImplicitPlugin creates a default plugin config struct for a connection
@@ -33,7 +36,7 @@ func NewImplicitPlugin(connection *Connection, imageRef string) *Plugin {
 }
 
 func (l *Plugin) OnDecoded(block *hcl.Block) {
-	pluginRange := hcl_helpers.BlockRange(block)
+	pluginRange := hclhelpers.BlockRange(block)
 	l.FileName = &pluginRange.Filename
 	l.StartLineNumber = &pluginRange.Start.Line
 	l.EndLineNumber = &pluginRange.End.Line
@@ -80,13 +83,12 @@ func (l *Plugin) Equals(other *Plugin) bool {
 // ResolvePluginImageRef resolves the plugin image ref from the plugin alias
 // (this handles the special case of locally developed plugins in the plugins/local folder)
 func ResolvePluginImageRef(pluginAlias string) string {
-	var imageRef string
 	if strings.HasPrefix(pluginAlias, `local/`) {
-		imageRef = pluginAlias
-	} else {
-		// ok so there is no plugin block reference - build the plugin image ref from the PluginAlias field
-		imageRef = ociinstaller.NewSteampipeImageRef(pluginAlias).DisplayImageRef()
+		// if a local plugin is specified, return the plugin alias as the image ref.
+		// this will be used as the path to the plugin in the local folder
+		return pluginAlias
 	}
-	//  are there any instances for this plugin
-	return imageRef
+	// ok so there is no plugin block reference - build the plugin image ref from the PluginAlias field
+	return ociinstaller.NewSteampipeImageRef(pluginAlias).DisplayImageRef()
 }
+
