@@ -2,9 +2,10 @@ package parse
 
 import (
 	"fmt"
+
 	"github.com/hashicorp/hcl/v2"
-	"github.com/turbot/go-kit/hcl_helpers"
 	"github.com/turbot/go-kit/helpers"
+	"github.com/turbot/pipe-fittings/hclhelpers"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 )
 
@@ -69,7 +70,7 @@ func checkForDuplicateChildren(names []string, block *hcl.Block) hcl.Diagnostics
 			diags = append(diags, &hcl.Diagnostic{
 				Severity: hcl.DiagError,
 				Summary:  fmt.Sprintf("'%s.%s' has duplicate child name '%s'", block.Type, block.Labels[0], n),
-				Subject:  hcl_helpers.BlockRangePointer(block)})
+				Subject:  hclhelpers.BlockRangePointer(block)})
 		}
 		nameMap[n] = nameCount + 1
 	}
