@@ -8,22 +8,32 @@ import (
 // cache resource schemas
 var resourceSchemaCache = make(map[string]*hcl.BodySchema)
 
-// TODO  [node_reuse] Replace all block type with consts https://github.com/turbot/steampipe/issues/2922
-
 var ConfigBlockSchema = &hcl.BodySchema{
 	Attributes: []hcl.AttributeSchema{},
 	Blocks: []hcl.BlockHeaderSchema{
 		{
-			Type:       "connection",
+			Type:       modconfig.BlockTypeConnection,
 			LabelNames: []string{"name"},
 		},
-
 		{
-			Type:       "options",
+			Type:       modconfig.BlockTypePlugin,
+			LabelNames: []string{"name"},
+		},
+		{
+			Type:       modconfig.BlockTypeOptions,
 			LabelNames: []string{"type"},
 		},
 		{
-			Type:       "workspace",
+			Type:       modconfig.BlockTypeWorkspaceProfile,
+			LabelNames: []string{"name"},
+		},
+	},
+}
+var PluginBlockSchema = &hcl.BodySchema{
+	Attributes: []hcl.AttributeSchema{},
+	Blocks: []hcl.BlockHeaderSchema{
+		{
+			Type:       modconfig.BlockTypeRateLimiter,
 			LabelNames: []string{"name"},
 		},
 	},
