@@ -1,21 +1,25 @@
 import { BasePrimitiveProps, ExecutablePrimitiveProps } from "../common";
+import { CategoryMap, NodeAndEdgeProperties } from "../common/types";
 import { ComponentType } from "react";
 import { NodeAndEdgeData } from "../graphs/types";
-import { NodeAndEdgeProperties } from "../common/types";
+import { PanelDefinition } from "../../../types";
 
-export type BaseFlowProps = BasePrimitiveProps & ExecutablePrimitiveProps;
+export type BaseFlowProps = PanelDefinition &
+  BasePrimitiveProps &
+  ExecutablePrimitiveProps;
 
 export type FlowProperties = NodeAndEdgeProperties;
 
-export interface FlowProps extends BaseFlowProps {
+export type FlowProps = BaseFlowProps & {
+  categories: CategoryMap;
   data?: NodeAndEdgeData;
   display_type?: FlowType;
   properties?: NodeAndEdgeProperties;
-}
+};
 
 export type FlowType = "sankey" | "table";
 
-export interface IFlow {
+export type IFlow = {
   type: FlowType;
   component: ComponentType<any>;
-}
+};
